@@ -170,7 +170,7 @@ class ListContainer(object):
             return ignore
         print >>ostream, ""
         i=0
-        for i in range(0, len(self._list)):
+        for i in xrange(len(self._list)):
             item = self._list[i]
             print >>ostream, prefix+'-',
             item.pprint(ostream, option, from_list=True, prefix=prefix+"  ", repn=repn[i])
