@@ -37,9 +37,12 @@ class SolutionMap(MapContainer):
             return self.__dict__[tmp]
         except:
             pass
-        self.declare_item(tmp)
+        if type(name) in (int,long):
+            self.declare_item(tmp-1)
+        else:
+            self.declare_item(tmp)
         if type(tmp) is int:
-            tmp = self._names[tmp]
+            tmp = self._names[tmp-1]
         item = dict.__getitem__(self, tmp)
         if isinstance(item,ListContainer) or isinstance(item,MapContainer):
             return item
@@ -47,10 +50,12 @@ class SolutionMap(MapContainer):
 
     def _set_value(self, name, val):
         #print "_set_value",name,val
-        if isinstance(name,basestring) or type(name) is int:
+        if isinstance(name,basestring):
             self.declare_item(name)
+        elif type(name) is int:
+            self.declare_item(name-1)
         if type(name) is int:
-            name = self._names[name]
+            name = self._names[name-1]
         dict.__getitem__(self, name).value = as_number(val)
         #print "_set_value",dict.__getitem__(self, name).value
 
@@ -230,8 +235,8 @@ class SolutionSet(ListContainer):
     def __len__(self):
         return len(self._list)
 
-    def __call__(self, i=0):
-        return self._list[i]
+    def __call__(self, i=1):
+        return self._list[i-1]
 
     def pprint(self, ostream, option, prefix="", repn=None):
         if not option.schema and not self._active and not self._required:
@@ -243,7 +248,7 @@ class SolutionSet(ListContainer):
             print >>ostream, prefix+spaces+key+":",repn[0][key]
             spaces="  "
         i=0
-        for i in range(0, len(self._list)):
+        for i in xrange(len(self._list)):
             item = self._list[i]
             print >>ostream, prefix+'-',
             item.pprint(ostream, option, from_list=True, prefix=prefix+"  ", repn=repn[i+1])
